/*******************************************************************************
  MPLAB Harmony Application Source File
  
  Company:
    Microchip Technology Inc.
  
  File Name:
    app.c

  Summary:
    This file contains the source code for the MPLAB Harmony application.

  Description:
    This file contains the source code for the MPLAB Harmony application.  It 
    implements the logic of the application's state machine and it may call 
    API routines of other MPLAB Harmony modules in the system, such as drivers,
    system services, and middleware.  However, it does not call any of the
    system interfaces (such as the "Initialize" and "Tasks" functions) of any of
    the modules in the system or make any assumptions about when those functions
    are called.  That is the responsibility of the configuration-specific system
    files.
 *******************************************************************************/

// DOM-IGNORE-BEGIN
/*******************************************************************************
Copyright (c) 2013-2014 released Microchip Technology Inc.  All rights reserved.

Microchip licenses to you the right to use, modify, copy and distribute
Software only when embedded on a Microchip microcontroller or digital signal
controller that is integrated into your product or third party product
(pursuant to the sublicense terms in the accompanying license agreement).

You should refer to the license agreement accompanying this Software for
additional information regarding your rights and obligations.

SOFTWARE AND DOCUMENTATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER
CONTRACT, NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR
OTHER LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR
CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF
SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
(INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.
 *******************************************************************************/
// DOM-IGNORE-END


// *****************************************************************************
// *****************************************************************************
// Section: Included Files 
// *****************************************************************************
// *****************************************************************************

#include "app.h"

// *****************************************************************************
// *****************************************************************************
// Section: Global Data Definitions
// *****************************************************************************
// *****************************************************************************

// *****************************************************************************
/* Application Data

  Summary:
    Holds application data

  Description:
    This structure holds the application's data.

  Remarks:
    This structure should be initialized by the APP_Initialize function.
    
    Application strings and buffers are be defined outside this structure.
*/

APP_DATA appData;

// *****************************************************************************
// *****************************************************************************
// Section: Application Callback Functions
// *****************************************************************************
// *****************************************************************************

/* TODO:  Add any necessary callback functions.
*/

// *****************************************************************************
// *****************************************************************************
// Section: Application Local Functions
// *****************************************************************************
// *****************************************************************************

/******************************************************************************
  Function:
    static void APP_OC_Task (void)
    
   Remarks:
    Generates a PWM (fixed pulse width) output on OCx pin.

*/

#define READ_CORE_TIMER()                 _CP0_GET_COUNT()          // Read the MIPS Core Timer
 
void BSP_DelayUs(uint16_t microseconds)
{
    uint32_t time;
    
    time = READ_CORE_TIMER(); // Read Core Timer    
    time += (SYS_CLK_FREQ / 2 / 1000 ) * microseconds; // calc the Stop Time    
    while ((int32_t)(time - READ_CORE_TIMER()) > 0){};    
}

uint32_t min0 = 1800 ;
uint32_t max0 = 3200 ;

uint32_t min1 = 0 ;
uint32_t max1 = 400 ;

static void APP_OC_Task (void)
{		
    char textToWrite[ 16 ];   
	switch(appData.ocStates)
	{
		default:
		
		case APP_OC_START:

			/* Start the output compare operation */
			DRV_OC_Start(appData.handleOC0, DRV_IO_INTENT_EXCLUSIVE);
            DRV_OC_Start(appData.handleOC1, DRV_IO_INTENT_EXCLUSIVE);
			
			/* Start Timer Driver */
			DRV_TMR_Start (appData.handleTMR1);		
            DRV_TMR_Start (appData.handleTMR2);
            DRV_TMR_Start (appData.handleTMR3);
			
			appData.ocStates = APP_OC_DONE;
			
			break;
			
		case APP_OC_DONE:
            
            sprintf(textToWrite,"%lu", appData.current);
            SYS_CONSOLE_PRINT(textToWrite);
            SYS_CONSOLE_PRINT("\r\n");
            
            int i;
            //DRV_OC_PulseWidthSet(appData.handleOC0, 2500);
            
            for (i = 0 ; i < 100 ; i++)
            {
                DRV_OC_PulseWidthSet(appData.handleOC0, min0+i*(max0-min0)/100);
                DRV_OC_PulseWidthSet(appData.handleOC1, min1+i*(max1-min1)/100);
                BSP_DelayUs(10);
            }
            for (i = 99 ; i > 0 ; i--)
            {
                DRV_OC_PulseWidthSet(appData.handleOC0, min0+i*(max0-min0)/100);
                DRV_OC_PulseWidthSet(appData.handleOC1, min1+i*(max1-min1)/100);
                BSP_DelayUs(10);
            }
            
            
			break;
	}
}

/* TODO:  Add any necessary local functions.
*/


// *****************************************************************************
// *****************************************************************************
// Section: Application Initialization and State Machine Functions
// *****************************************************************************
// *****************************************************************************

/*******************************************************************************
  Function:
    void APP_Initialize ( void )

  Remarks:
    See prototype in app.h.
 */

void APP_Initialize ( void )
{
    /* Place the App state machine in its initial state. */
    appData.state = APP_STATE_INIT;

    appData.handleOC0 = DRV_HANDLE_INVALID;
	appData.handleTMR1 = DRV_HANDLE_INVALID;
    
    appData.handleOC1 = DRV_HANDLE_INVALID;
	appData.handleTMR2 = DRV_HANDLE_INVALID;
    
    appData.handleTMR3 = DRV_HANDLE_INVALID;
    
    /* TODO: Initialize your application's state machine and other
     * parameters.
     */
}


/******************************************************************************
  Function:
    void APP_Tasks ( void )

  Remarks:
    See prototype in app.h.
 */

void APP_Tasks ( void )
{

    /* Check the application's current state. */
    switch ( appData.state )
    {
        /* Application's initial state. */
        case APP_STATE_INIT:
        {
            bool appInitialized = true;
       
            /* Open the IC driver if it has not been previously opened */
            if (appData.handleOC0 == DRV_HANDLE_INVALID)
            {
                appData.handleOC0 = DRV_OC_Open(0, DRV_IO_INTENT_EXCLUSIVE);
                DRV_OC_PulseWidthSet(appData.handleOC0, 0); //8000
                appInitialized &= ( DRV_HANDLE_INVALID != appData.handleOC0 );
            }

			if (appData.handleTMR1 == DRV_HANDLE_INVALID)
            {
                appData.handleTMR1 = DRV_TMR_Open(1, DRV_IO_INTENT_EXCLUSIVE);
                appInitialized &= ( DRV_HANDLE_INVALID != appData.handleTMR1 );
            }
            
            if (appData.handleOC1 == DRV_HANDLE_INVALID)
            {
                appData.handleOC1 = DRV_OC_Open(1, DRV_IO_INTENT_EXCLUSIVE);
                DRV_OC_PulseWidthSet(appData.handleOC1, 0); //625
                appInitialized &= ( DRV_HANDLE_INVALID != appData.handleOC1 );
            }

			if (appData.handleTMR2 == DRV_HANDLE_INVALID)
            {
                appData.handleTMR2 = DRV_TMR_Open(2, DRV_IO_INTENT_EXCLUSIVE);
                appInitialized &= ( DRV_HANDLE_INVALID != appData.handleTMR2 );
            }
            
            if (appData.handleTMR3 == DRV_HANDLE_INVALID)
            {
                appData.handleTMR3 = DRV_TMR_Open(3, DRV_IO_INTENT_EXCLUSIVE);
                appInitialized &= ( DRV_HANDLE_INVALID != appData.handleTMR3 );
            }
            
            
            
            
            if (appInitialized)
            {
                DRV_ADC0_Open();
                appData.current=0;
                PLIB_PORTS_PinSet (PORTS_ID_0, PORT_CHANNEL_K, PORTS_BIT_POS_6);
                appData.state = APP_STATE_SERVICE_TASKS;
            }
            break;
        }

        case APP_STATE_SERVICE_TASKS:
        {
		    /* Run the state machine for servicing Input Capture */
            APP_OC_Task();
			
            break;
        }

        /* TODO: implement your application state machine.*/
        

        /* The default state should never be executed. */
        default:
        {
            /* TODO: Handle error in application's state machine. */
            break;
        }
    }
}

 

/*******************************************************************************
 End of File
 */
